==> xpi-forecastfox-0.9.3.1.tbz: lib/xpi/{0538E3E3-7E9B-4d49-8831-A227C80A7AD3}/defaults/preferences/forecastfox.js <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Forecastfox.
 *
 * The Initial Developer of the Original Code is
 * Jon Stritar <jstritar@MIT.EDU>.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * Jon Stritar <jstritar@MIT.EDU>
 * Richard Klein <richwklein@mchsi.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

//localized prefs
pref("extensions.{0538E3E3-7E9B-4d49-8831-A227C80A7AD3}.description", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.cc.panel.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.cc.tooltip.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.cc.tooltip.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.cc.slider.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.cc.slider.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.dayt.panel.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.dayt.tooltip.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.dayt.tooltip.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.dayf.panel.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.dayf.tooltip.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.dayf.tooltip.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.radar.panel.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.radar.tooltip.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.radar.tooltip.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.swa.panel.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.swa.tooltip.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.swa.tooltip.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.swa.slider.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.swa.slider.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.current", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.degrees.0", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.degrees.1", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.pressure.0", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.pressure.1", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.temp.0", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.temp.1", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.speed.0", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.speed.1", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.dist.0", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.dist.1", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.precip.0", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.precip.1", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.percent.0", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.units.percent.1", "chrome://forecastfox/locale/forecastfox.properties");
 
//global prefs
pref("forecastfox.migrated", "");
pref("forecastfox.pinged", "");
pref("forecastfox.migrated.prefs", false);
pref("forecastfox.icons.current", "default");
pref("forecastfox.icons.version", "1.0");
pref("forecastfox.icons.uninstallfiles", "");
pref("forecastfox.profile.current", "default");
pref("forecastfox.profile.switch.enabled", false);
pref("forecastfox.profile.switch.delay", 2);
pref("forecastfox.schedule.bump", 200);          //over 100 multiply by span on +
pref("forecastfox.schedule.span", 16);           //minutes between 2 schedules
pref("extensions.{0538E3E3-7E9B-4d49-8831-A227C80A7AD3}.description", "chrome://forecastfox/locale/forecastfox.properties");

//general prefs
pref("forecastfox.general.locid", "00000");
pref("forecastfox.general.bar", "status-bar");
pref("forecastfox.general.position", -1);       //0 based -> -1 means "last element"
pref("forecastfox.general.last", "0");
pref("forecastfox.general.cache", "");
pref("forecastfox.general.freq", 30);

//link prefs
pref("forecastfox.links.alert", "current");
pref("forecastfox.links.dialog", "window");
pref("forecastfox.links.panel", "current");
pref("forecastfox.links.context", "current");

//radar
pref("forecastfox.radar.cache", "");
pref("forecastfox.radar.panel.enabled", true);
pref("forecastfox.radar.panel.display", 0);        //0=icon, 1=label, 2=both
pref("forecastfox.radar.tooltip.enabled", true);
pref("forecastfox.radar.tooltip.display", 0);      //0=icon, 1=label, 2=both

//severe weather alerts
pref("forecastfox.swa.panel.enabled", true);
pref("forecastfox.swa.panel.display", 0);        //0=icon, 1=label, 2=both
pref("forecastfox.swa.tooltip.enabled", true);
pref("forecastfox.swa.tooltip.display", 1);      //0=icon, 1=label, 2=both
pref("forecastfox.swa.slider.enabled", true);
pref("forecastfox.swa.slider.display", 2);       //0=icon, 1=label, 2=both
pref("forecastfox.swa.slider.freq", 2);
pref("forecastfox.swa.slider.count", 1);

//current condition prefs
pref("forecastfox.cc.panel.enabled", true);
pref("forecastfox.cc.panel.display", 0);        //0=icon, 1=label, 2=both
pref("forecastfox.cc.tooltip.enabled", true);
pref("forecastfox.cc.tooltip.display", 2);      //0=icon, 1=label, 2=both
pref("forecastfox.cc.slider.freq", 2);
pref("forecastfox.cc.slider.count", 1);
pref("forecastfox.cc.slider.enabled", true);
pref("forecastfox.cc.slider.display", 2);       //0=icon, 1=label, 2=both

//today prefs
pref("forecastfox.dayt.panel.enabled", true);
pref("forecastfox.dayt.panel.display", 0);        //0=icon, 1=label, 2=both
pref("forecastfox.dayt.tooltip.enabled", true);
pref("forecastfox.dayt.tooltip.display", 2);      //0=icon, 1=label, 2=both
pref("forecastfox.dayt.panel.mode", 0);           //0=today, 1=tonight, 2=both
pref("forecastfox.dayt.panel.switch", 1);         //0=switch to tonight, 1= switch to tomorrow, 2 = disappear

//forecast prefs
pref("forecastfox.dayf.panel.mode", 0);           //0=day, 1=night, 2=both 
pref("forecastfox.dayf.panel.days", 1);
pref("forecastfox.dayf.panel.enabled", true);
pref("forecastfox.dayf.panel.display", 0);        //0=icon, 1=label, 2=both
pref("forecastfox.dayf.tooltip.enabled", true);
pref("forecastfox.dayf.tooltip.display", 2);      //0=icon, 1=label, 2=both

==> xpi-forecastfox-0.9.8.tbz: lib/xpi/{0538E3E3-7E9B-4d49-8831-A227C80A7AD3}/defaults/preferences/forecastfox.js <==
//global prefs
pref("extensions.{0538E3E3-7E9B-4d49-8831-A227C80A7AD3}.description", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.migrated", "");
pref("forecastfox.migrated.prefs", false);
pref("forecastfox.pinged", "");
pref("forecastfox.icons.current", "default");
pref("forecastfox.icons.version", "1.0");
pref("forecastfox.icons.uninstallfiles", "");
pref("forecastfox.profile.current", "default");
pref("forecastfox.profile.switch.enabled", false);
pref("forecastfox.profile.switch.delay", 2);
pref("forecastfox.units.current", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.preview.tooltip.enabled", false);

//general prefs
pref("forecastfox.general.locid", "00000");
pref("forecastfox.general.bar", "status-bar");
pref("forecastfox.general.position", -1);       //0 based -> -1 means "last element"
pref("forecastfox.general.last", "0");
pref("forecastfox.general.delay", 30);
pref("forecastfox.general.radar", "0");

//link prefs
pref("forecastfox.links.alert", "current");
pref("forecastfox.links.dialog", "window");
pref("forecastfox.links.panel", "current");
pref("forecastfox.links.context", "current");

//radar
pref("forecastfox.radar.panel.enabled", true);
pref("forecastfox.radar.panel.display", 0);        //0=icon, 1=label, 2=both
pref("forecastfox.radar.panel.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.radar.tooltip.enabled", true);
pref("forecastfox.radar.tooltip.display", 0);      //0=icon, 1=label, 2=both
pref("forecastfox.radar.tooltip.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.radar.tooltip.label", "chrome://forecastfox/locale/forecastfox.properties");

//severe weather alerts
pref("forecastfox.swa.panel.enabled", true);
pref("forecastfox.swa.panel.display", 0);        //0=icon, 1=label, 2=both
pref("forecastfox.swa.panel.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.swa.tooltip.enabled", true);
pref("forecastfox.swa.tooltip.display", 1);      //0=icon, 1=label, 2=both
pref("forecastfox.swa.tooltip.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.swa.tooltip.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.swa.slider.freq", 2);
pref("forecastfox.swa.slider.count", 1);
pref("forecastfox.swa.slider.enabled", true);
pref("forecastfox.swa.slider.display", 2);       //0=icon, 1=label, 2=both
pref("forecastfox.swa.slider.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.swa.slider.label", "chrome://forecastfox/locale/forecastfox.properties");

//current condition prefs
pref("forecastfox.cc.panel.enabled", true);
pref("forecastfox.cc.panel.display", 2);        //0=icon, 1=label, 2=both
pref("forecastfox.cc.panel.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.cc.tooltip.enabled", true);
pref("forecastfox.cc.tooltip.display", 2);      //0=icon, 1=label, 2=both
pref("forecastfox.cc.tooltip.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.cc.tooltip.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.cc.slider.freq", 2);
pref("forecastfox.cc.slider.count", 1);
pref("forecastfox.cc.slider.enabled", true);
pref("forecastfox.cc.slider.display", 2);       //0=icon, 1=label, 2=both
pref("forecastfox.cc.slider.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.cc.slider.label", "chrome://forecastfox/locale/forecastfox.properties");

//today prefs
pref("forecastfox.dayt.panel.mode", 0);           //0=today, 1=tonight, 2=both
pref("forecastfox.dayt.panel.switch", 1);         //0=switch to tonight, 1= switch to tomorrow, 2 = disappear
pref("forecastfox.dayt.panel.enabled", true);
pref("forecastfox.dayt.panel.display", 2);        //0=icon, 1=label, 2=both
pref("forecastfox.dayt.panel.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.dayt.tooltip.enabled", true);
pref("forecastfox.dayt.tooltip.display", 2);      //0=icon, 1=label, 2=both
pref("forecastfox.dayt.tooltip.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.dayt.tooltip.label", "chrome://forecastfox/locale/forecastfox.properties");

//forecast prefs
pref("forecastfox.dayf.panel.mode", 0);           //0=day, 1=night, 2=both 
pref("forecastfox.dayf.panel.days", 1);
pref("forecastfox.dayf.panel.enabled", true);
pref("forecastfox.dayf.panel.display", 2);        //0=icon, 1=label, 2=both
pref("forecastfox.dayf.panel.label", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.dayf.tooltip.enabled", true);
pref("forecastfox.dayf.tooltip.display", 2);      //0=icon, 1=label, 2=both
pref("forecastfox.dayf.tooltip.title", "chrome://forecastfox/locale/forecastfox.properties");
pref("forecastfox.dayf.tooltip.label", "chrome://forecastfox/locale/forecastfox.properties");
